################################################################################
# File:             compDeepestCurve.R
# Created by:       Pierre Lafaye De Micheaux
# First released:   06.11.2018
# Last revised:     06.11.2018
# 
# Contains R-script for computation of the computation of the deepest curve in 
# a bundle.
# 
# For a detailed description see:
#   Lafaye De Micheaux, P., Mozharovskyi, P. and Vimond, M. (2018). Depth for 
#     curve data and applications.
################################################################################

filename <- paste(code, "_1_dwi.voxelcoordsL.txt", sep = "")
#setwd("/home/z3458242/MRI")
source("../DTI.R")


# Load necessary R packages

require("curveDepth")
require("AnalyzeFMRI")

# Read fibers file
fibers.Left <- f.read.fibers(fibers.file = paste("../Data/", filename, sep = ""))
fibers.Left.coord <- fibers.Left$fibers.coordinates
fibers.Left.nb <- fibers.Left$nbfibers
fibers.Left.min.nbpoints <- min(fibers.Left$vect.of.nbpts.per.fiber)

n <- fibers.Left.nb # Number of curves taken from each side of the brain. It is 1,000 for this specific example

# Left side
leftFibers <- list("")
for (j in 1:n) {
  f1 <- fibers.Left$indices.of.fibers[j, 1]
  f2 <- fibers.Left$indices.of.fibers[j, 2]
  x <- fibers.Left.coord[f1:f2, 1]
  y <- fibers.Left.coord[f1:f2, 2]
  z <- fibers.Left.coord[f1:f2, 3]
  leftFibers[[j]] <- list(voxels = 0, coords = cbind(x, y, z))
}

set.seed(1)

search.for.deepest.curves <- function(Fibers = leftFibers, nbtries = 200, k = floor(n ^ 0.8), ptsPerCurve = 256) {
    deepest <- rep(NA, nbtries)
    n <- length(Fibers)
    leftFibersk <- list("")
    for (l in 1:nbtries) {
        subSamp <- sample(1:n, k)
        for (j in 1:k) leftFibersk[[j]] <- Fibers[[subSamp[j]]]
        leftFibersSmplk <- sample.curves(leftFibersk, ptsPerCurve = ptsPerCurve)
        dssLeft <- depth.curve.Tukey(leftFibersSmplk, leftFibersSmplk, exactEst = FALSE)
        deepest[l] <- subSamp[which.max(dssLeft)]
    }
    return(deepest)
}

time <- system.time({deepest <- search.for.deepest.curves()})
print(time)
tbl <- table(deepest)
max.tbl <- max(tbl)
deepest.curve <- as.numeric(names(which.max(tbl)))
print(deepest.curve)

write(deepest.curve, file = paste("deepest-curve-", code, ".txt", sep = ""))

save.image(file = paste(code, "-deepest-curve.RData", sep = ""))


